# Blueprints-hello

Blueprints is a library to perform auto-discovery of Flask blueprints
by scanning the installed packages for blueprints.txt files.
This is an example of an auto-discoverable project.

## Installation

    pip install --upgrade auto-blueprints-hello

## Running

Blueprints can be run as a command line executable.

    blueprints --host 127.0.0.1 --port 5000

## License

MIT Licensed
